package com.muyu.etl.domain.req;

import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.constraints.NotEmpty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

/**
 * @version 1.0
 * @Author xie ya ru
 * @Date 2024/8/19 19:14
 * @注释
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Tag(name = "添加数据源信息" ,description = "数据源详细信息的添加")
public class DataSourceAddReq {
    /**
     * 数据源类型
     */
    @NotEmpty(message = "数据来源不可为空")
    @Schema(type = "String",defaultValue = "MySQL",description = "数据信息来源的信息名称",requiredProperties = "true")
    private String   databaseType;
    /**
     * 数据源名称
     */
    @NotEmpty(message = "数据源名称不可为空")
    @Schema(type = "String",defaultValue = "cloud-app",description = "数据源的来源的名称",requiredProperties = "true")
    private String databaseFormName;
    /**
     * 数据来源地址
     */
    @NotEmpty(message = "数据来源地址不可为空")
    @Schema(type = "String",defaultValue = "127.0.0.1",description = "数据来源地址",requiredProperties = "true")
    private String databaseUrl;
    /**
     * 来源地址端口号
     */
    @Schema(type = "String",defaultValue = "3306",description = "来源地址端口号")
    private String databasePost;
    /**
     * 数据库名称
     */
    @Schema(type = "String",defaultValue = "cloud-server",description = "数据库名称")
    private String databaseName;
    /**
     * 表名称
     */
    @Schema(type = "String",defaultValue = "t_student",description = "表名称")
    private String tableName;
    /**
     * 数据库登录名
     */
    @Schema(type = "String",defaultValue = "root",description = "数据库登录名")
    private String userName;
    /**
     * 数据库登录密码
     */
    @Schema(type = "String",defaultValue = "wuzuxiaoniu@123.",description = "数据库登录密码")
    private String userPwd;

}
